@@ -1,9 +1,11 @@
 test_that("omega inv sqrt monovar", {
-  expect_equal(omega_inv_sqrt(ts(c(1,5,6,7),start=2010,frequency = 12),0.5) %>% unname,
-               ts(c(sqrt(0.75),4.5,3.5,4),start=2010,frequency = 12))
+  expect_equal(omega_inv_sqrt(c(1,5,6,7),0.5) %>% unname,
+               c(sqrt(0.75),4.5,3.5,4))
 })
 
 test_that("error praislm", {
+  expect_error(praislm(ts(matrix(1:10,ncol=1),start=2011),ts(matrix(1:10,ncol=1),start=2010),FALSE,FALSE,numeric(),NULL),
+               "same windows and frequencies")
   expect_error(praislm(1:120,ts(1:10,frequency=1,start=2010),
                      TRUE,numeric(),NULL),"ts object")
   expect_error(praislm(ts(1:120,frequency=12,start=2010),1:10,
